summaryrefslogtreecommitdiff
path: root/tests/cache
diff options
context:
space:
mode:
Diffstat (limited to 'tests/cache')
-rw-r--r--tests/cache/tests.py19
1 files changed, 10 insertions, 9 deletions
diff --git a/tests/cache/tests.py b/tests/cache/tests.py
index 7172b5e9d9..df0483d26e 100644
--- a/tests/cache/tests.py
+++ b/tests/cache/tests.py
@@ -17,7 +17,8 @@ from unittest import mock, skipIf
from django.conf import settings
from django.core import management, signals
from django.core.cache import (
- DEFAULT_CACHE_ALIAS, CacheKeyWarning, InvalidCacheKey, cache, caches,
+ DEFAULT_CACHE_ALIAS, CacheHandler, CacheKeyWarning, InvalidCacheKey, cache,
+ caches,
)
from django.core.cache.backends.base import InvalidCacheBackendError
from django.core.cache.utils import make_template_fragment_key
@@ -2501,19 +2502,19 @@ class CacheHandlerTest(SimpleTestCase):
self.assertIsNot(c[0], c[1])
def test_nonexistent_alias(self):
- msg = "Could not find config for 'nonexistent' in settings.CACHES"
+ msg = "The connection 'nonexistent' doesn't exist."
with self.assertRaisesMessage(InvalidCacheBackendError, msg):
caches['nonexistent']
def test_nonexistent_backend(self):
+ test_caches = CacheHandler({
+ 'invalid_backend': {
+ 'BACKEND': 'django.nonexistent.NonexistentBackend',
+ },
+ })
msg = (
"Could not find backend 'django.nonexistent.NonexistentBackend': "
"No module named 'django.nonexistent'"
)
- with self.settings(CACHES={
- 'invalid_backend': {
- 'BACKEND': 'django.nonexistent.NonexistentBackend',
- },
- }):
- with self.assertRaisesMessage(InvalidCacheBackendError, msg):
- caches['invalid_backend']
+ with self.assertRaisesMessage(InvalidCacheBackendError, msg):
+ test_caches['invalid_backend']